Unescaped markup ▲ Prism plugins

# How to use

This plugin provides several methods of achieving the same thing:

- Instead of using `<pre><code>` elements, use `<script type="text/plain">`
- Use a HTML-comment to escape your code

      <pre><code><!--
      <p>Example</p>
      --></pre></code>

# Examples

View source to see that the following didn’t need escaping (except for `</script>`, that does):

The next example uses the HTML-comment method:

# FAQ

Why not use the HTML `<template>` tag?

Because it is a PITA to get its `textContent` and needs to be pointlessly cloned. Feel free to implement it yourself and send a pull request though, if you are so inclined.

Can I use this inline?

Not out of the box, because I figured it’s more of a hassle to type `<script type="text/plain">` than escape the 1-2 `<` characters you need to escape in inline code. Also inline code is not as frequently copy-pasted, which was the major source of annoyance that got me to write this plugin.